@@ -1,12 +1,16 @@
 package ca.ubc.cs.beta.smac.builder;
 
 import java.io.File;
+
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+
 import com.beust.jcommander.ParameterException;
 
 import ca.ubc.cs.beta.aclib.acquisitionfunctions.AcquisitionFunctions;
@@ -16,8 +20,10 @@ import ca.ubc.cs.beta.aclib.configspace.ParamConfiguration.StringFormat;
 import ca.ubc.cs.beta.aclib.configspace.tracking.ParamConfigurationOriginTracker;
 import ca.ubc.cs.beta.aclib.eventsystem.EventManager;
 import ca.ubc.cs.beta.aclib.eventsystem.events.ac.AutomaticConfigurationEnd;
+import ca.ubc.cs.beta.aclib.eventsystem.events.ac.ChallengeEndEvent;
 import ca.ubc.cs.beta.aclib.eventsystem.events.ac.ChallengeStartEvent;
 import ca.ubc.cs.beta.aclib.eventsystem.events.ac.IncumbentPerformanceChangeEvent;
+import ca.ubc.cs.beta.aclib.eventsystem.events.ac.IterationStartEvent;
 import ca.ubc.cs.beta.aclib.eventsystem.events.basic.AlgorithmRunCompletedEvent;
 import ca.ubc.cs.beta.aclib.eventsystem.events.model.ModelBuildEndEvent;
 import ca.ubc.cs.beta.aclib.eventsystem.events.model.ModelBuildStartEvent;
@@ -28,6 +34,7 @@ import ca.ubc.cs.beta.aclib.initialization.InitializationProcedure;
 import ca.ubc.cs.beta.aclib.initialization.classic.ClassicInitializationProcedure;
 import ca.ubc.cs.beta.aclib.initialization.doublingcapping.DoublingCappingInitializationProcedure;
 import ca.ubc.cs.beta.aclib.initialization.table.UnbiasChallengerInitializationProcedure;
+import ca.ubc.cs.beta.aclib.misc.cputime.CPUTime;
 import ca.ubc.cs.beta.aclib.objectives.ObjectiveHelper;
 import ca.ubc.cs.beta.aclib.objectives.OverallObjective;
 import ca.ubc.cs.beta.aclib.objectives.RunObjective;
@@ -66,8 +73,7 @@ public class SMACBuilder {
 	private final EventManager eventManager; 
 	
 	private volatile TrajectoryFileLogger tLog;
-	
-	
+
 	private volatile LogRuntimeStatistics logRT;
 	public SMACBuilder()
 	{
@@ -82,13 +88,15 @@ public class SMACBuilder {
 	
 	public AbstractAlgorithmFramework getAutomaticConfigurator(AlgorithmExecutionConfig execConfig, InstanceListWithSeeds trainingILWS, SMACOptions options,Map<String, AbstractOptions> taeOptions, String outputDir, SeedableRandomPool pool)
 	{	
+		CPUTime cpuTime = new CPUTime();
+		
 		StateFactory restoreSF = options.getRestoreStateFactory(outputDir);
 		
 		
 
 		if(options.adaptiveCapping == null)
 		{
-			switch(options.scenarioConfig.runObj)
+			switch(options.scenarioConfig.getRunObjective())
 			{
 			case RUNTIME:
 				options.adaptiveCapping = true;
@@ -106,7 +114,7 @@ public class SMACBuilder {
 		
 		if(options.randomForestOptions.logModel == null)
 		{
-			switch(options.scenarioConfig.runObj)
+			switch(options.scenarioConfig.getRunObjective())
 			{
 			case RUNTIME:
 				options.randomForestOptions.logModel = true;
@@ -122,7 +130,15 @@ public class SMACBuilder {
 		
 		ParamConfigurationSpace configSpace = execConfig.getParamFile();
 		
-		log.info("Configuration Space Size is less than or equal to {} ", configSpace.getUpperBoundOnSize());
+		double configSpaceSize = configSpace.getUpperBoundOnSize();
+	
+		if(Double.isInfinite(configSpaceSize))
+		{
+			log.debug("Configuration Space has at least one continuous parameter or is very large (only bound expressible in IEEE 754 format is Infinity)");
+		} else
+		{
+			log.debug("Configuration Space size is at most {}", configSpace.getUpperBoundOnSize());
+		}
 		
 		StateFactory sf = options.getSaveStateFactory(outputDir);
 		
@@ -137,10 +153,10 @@ public class SMACBuilder {
 		
 		if(!initialIncumbent.equals(configSpace.getDefaultConfiguration()))
 		{
-			log.info("Initial Incumbent set to \"{}\" ", initialIncumbent.getFormattedParamString(StringFormat.NODB_SYNTAX));
+			log.debug("Initial Incumbent set to \"{}\" ", initialIncumbent.getFormattedParamString(StringFormat.NODB_SYNTAX));
 		} else
 		{
-			log.info("Initial Incumbent is the default \"{}\" ", initialIncumbent.getFormattedParamString(StringFormat.NODB_SYNTAX));
+			log.debug("Initial Incumbent is the default \"{}\" ", initialIncumbent.getFormattedParamString(StringFormat.NODB_SYNTAX));
 		}
 		
 		validateObjectiveCombinations(options.scenarioConfig, options.adaptiveCapping);
@@ -149,24 +165,30 @@ public class SMACBuilder {
 		
 		AbstractAlgorithmFramework smac;
 
-		RunHistory rhROAR = new NewRunHistory(options.scenarioConfig.intraInstanceObj, options.scenarioConfig.interInstanceObj, options.scenarioConfig.runObj);
-		RunHistory rhModel = new NewRunHistory(options.scenarioConfig.intraInstanceObj, options.scenarioConfig.interInstanceObj, options.scenarioConfig.runObj);
+		RunHistory rhROAR = new NewRunHistory(options.scenarioConfig.getIntraInstanceObjective(), options.scenarioConfig.interInstanceObj, options.scenarioConfig.getRunObjective());
+		RunHistory rhModel = new NewRunHistory(options.scenarioConfig.getIntraInstanceObjective(), options.scenarioConfig.interInstanceObj, options.scenarioConfig.getRunObjective());
 		
 		
 		ThreadSafeRunHistory rh = new ThreadSafeRunHistoryWrapper(new TeeRunHistory(rhROAR, rhModel));
 		
-		CompositeTerminationCondition termCond = options.scenarioConfig.limitOptions.getTerminationConditions();
+		
+		CompositeTerminationCondition termCond = options.scenarioConfig.limitOptions.getTerminationConditions(cpuTime);
 		
 		
 
 		
-		tLog = new TrajectoryFileLogger(rh, termCond, outputDir +  File.separator + "traj-run-" + options.seedOptions.numRun, initialIncumbent);
+		tLog = new TrajectoryFileLogger(rh, termCond, outputDir +  File.separator + "traj-run-" + options.seedOptions.numRun, initialIncumbent, cpuTime);
 		eventManager.registerHandler(IncumbentPerformanceChangeEvent.class, tLog);
 		eventManager.registerHandler(AutomaticConfigurationEnd.class, tLog);
 		
 
 		
-		logRT = new LogRuntimeStatistics(rh, termCond, execConfig.getAlgorithmCutoffTime(),tae);
+		Set onEvents = new HashSet();
+		
+		onEvents.add(IterationStartEvent.class);
+		onEvents.add(AutomaticConfigurationEnd.class);
+		
+		logRT = new LogRuntimeStatistics(rh, termCond, execConfig.getAlgorithmCutoffTime(),tae,false, cpuTime, onEvents);
 		termCond.registerWithEventManager(eventManager);	
 		eventManager.registerHandler(ModelBuildStartEvent.class, logRT);
 		eventManager.registerHandler(IncumbentPerformanceChangeEvent.class,logRT);
@@ -174,6 +196,10 @@ public class SMACBuilder {
 		eventManager.registerHandler(AutomaticConfigurationEnd.class, logRT);
 		eventManager.registerHandler(StateRestoredEvent.class, logRT);
 		
+		eventManager.registerHandler(ChallengeStartEvent.class, logRT);
+		eventManager.registerHandler(ChallengeEndEvent.class, logRT);
+		eventManager.registerHandler(IterationStartEvent.class, logRT);
+		
 		ParamConfigurationOriginTracker configTracker = options.trackingOptions.getTracker(eventManager, initialIncumbent, outputDir, rh, execConfig, options.seedOptions.numRun);
 		
 		
@@ -182,7 +208,7 @@ public class SMACBuilder {
 		
 		InitializationProcedure initProc;
 		
-		ObjectiveHelper objHelper = new ObjectiveHelper(options.scenarioConfig.runObj, options.scenarioConfig.intraInstanceObj, options.scenarioConfig.interInstanceObj, execConfig.getAlgorithmCutoffTime());
+		ObjectiveHelper objHelper = new ObjectiveHelper(options.scenarioConfig.getRunObjective(), options.scenarioConfig.getIntraInstanceObjective(), options.scenarioConfig.interInstanceObj, execConfig.getAlgorithmCutoffTime());
 		
 		switch(options.initializationMode)
 		{
@@ -211,7 +237,7 @@ public class SMACBuilder {
 		
 		if(options.expFunc == null)
 		{
-			switch(options.scenarioConfig.runObj)
+			switch(options.scenarioConfig.getRunObjective())
 			{
 			case RUNTIME:
 				options.expFunc = AcquisitionFunctions.EXPONENTIAL;
@@ -256,11 +282,11 @@ public class SMACBuilder {
 		switch(options.execMode)
 		{
 			case ROAR:
-				smac = new AbstractAlgorithmFramework(options,instances,acTae,sf, configSpace, instanceSeedGen, initialIncumbent, eventManager, rh, pool, termCond, configTracker, initProc);
+				smac = new AbstractAlgorithmFramework(options,instances,acTae,sf, configSpace, instanceSeedGen, initialIncumbent, eventManager, rh, pool, termCond, configTracker, initProc, cpuTime);
 				break;
 			case SMAC:
 				options.warmStartOptions.getWarmStartState(configSpace, instances, execConfig, rhModel);
-				smac = new SequentialModelBasedAlgorithmConfiguration(options, instances, acTae, options.expFunc.getFunction(),sf, configSpace, instanceSeedGen, initialIncumbent, eventManager, rh,pool, termCond, configTracker, initProc, rhModel);
+				smac = new SequentialModelBasedAlgorithmConfiguration(options, instances, acTae, options.expFunc.getFunction(),sf, configSpace, instanceSeedGen, initialIncumbent, eventManager, rh,pool, termCond, configTracker, initProc, rhModel, cpuTime);
 				break;
 			case PSEL:
 				throw new ParameterException("This version of SMAC does not support " + options.execMode + " at this time");
@@ -334,13 +360,13 @@ public class SMACBuilder {
 		
 		
 		
-		switch(scenarioOptions.runObj)
+		switch(scenarioOptions.getRunObjective())
 		{
 			case RUNTIME:
 				break;
 			
 			case QUALITY:
-				if(!scenarioOptions.intraInstanceObj.equals(OverallObjective.MEAN))
+				if(!scenarioOptions.getIntraInstanceObjective().equals(OverallObjective.MEAN))
 				{
 					throw new ParameterException("To optimize quality you MUST use an intra-instance objective of " + OverallObjective.MEAN);
 				}
